/**
  *  \file game/fleet.h
  *  \brief Fleets
  *
  *  (c) 2001-2012 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_GAME_FLEET_H
#define PCC_V2_GAME_FLEET_H

#include "cpluslib/string.h"
#include "game/objtypes.h"
#include "game/ship.h"

class Directory;
class GGameTurn;
class GUniverse;

class GFleetType : public GIndexedObjectType {
 public:
    GFleetType();

    bool isExistant(int index);
    GShip& getObject(int index);

    void handleFleetChange(int hintfid);
};

// Load & Save (work with GGameTurn)
void loadFleets(GGameTurn& trn, Directory& dir, int player);
void saveFleets(const GGameTurn& trn, Directory& dir, int player);
void postprocessFleets(GGameTurn& trn);

// Operations (work with GUniverse)
void leaveFleet(GUniverse& univ, int sid);
void synchronizeFleetMember(GUniverse& univ, int sid);
void synchronizeFleet(GUniverse& univ, int fid);

void markFleetDirty(GUniverse& univ, int fid);

bool setFleetNumber(GUniverse& univ, int sid, int nfid);
bool setFleetName(GUniverse& univ, int sid, string_t nname);
bool setFleetWaypoint(GUniverse& univ, int sid, GPoint pt);
bool setFleetSpeed(GUniverse& univ, int sid, int speed);
bool setFleetMission(GUniverse& univ, int sid, int m, int i, int t);

string_t getFleetTitle(const GUniverse& univ, int fid);

// Mission lock
enum {
    mlAcceptLeaders = 1,
    mlOverrideLocks = 2
};
bool isMissionLocked(const GShip& sh, int flags);

#endif
